@@ -397,14 +397,14 @@ class Text(JupyterMixin):
         Returns:
             Style: A Style instance.
         """
+        # TODO: This is a little inefficient, it is only used by full justify
         if offset < 0:
             offset = len(self) + offset
-
         get_style = console.get_style
         style = get_style(self.style).copy()
         for start, end, span_style in self._spans:
-            if offset >= start and offset < end:
-                style += get_style(span_style)
+            if end > offset >= start:
+                style += get_style(span_style, default="")
         return style
 
     def highlight_regex(
@@ -687,7 +687,6 @@ class Text(JupyterMixin):
 
     def _trim_spans(self) -> None:
         """Remove or modify any spans that are over the end of the text."""
-        # new_length = self._length
         max_offset = len(self.plain)
         _Span = Span
         self._spans[:] = [
@@ -1115,20 +1114,27 @@ class Text(JupyterMixin):
 
 
 if __name__ == "__main__":  # pragma: no cover
-    from rich import print
+    from rich.console import Console
 
-    text = Text("<span>\n\tHello\n</span>")
-    text.expand_tabs(4)
-    print(text)
+    text = Text(
+        """\nLorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.\n"""
+    )
+    text.highlight_words(["Lorem"], "bold")
+    text.highlight_words(["ipsum"], "italic")
 
-    code = """
-def __add__(self, other: Any) -> "Text":
-    if isinstance(other, (str, Text)):
-        result = self.copy()
-        result.append(other)
-        return result
-    return NotImplemented
-"""
-    text = Text(code)
-    text = text.with_indent_guides()
-    print(text)
+    console = Console()
+    console.rule("justify='left'")
+    console.print(text, style="red")
+    console.print()
+
+    console.rule("justify='center'")
+    console.print(text, style="green", justify="center")
+    console.print()
+
+    console.rule("justify='right'")
+    console.print(text, style="blue", justify="right")
+    console.print()
+
+    console.rule("justify='full'")
+    console.print(text, style="magenta", justify="full")
+    console.print()
